//---------------------------------------------------------------------------

#ifndef ArmScopeH
#define ArmScopeH
//---------------------------------------------------------------------------

#include "..\miniscope\device\MiniscopeDeviceCapabilities.h"

class TestScope
{
private:
	bool bDeviceOpened;
	bool bStopRequest;
	struct {
		float fDivX;
		float fDivY;
		int samples;
		int triggerval;
	} settings;

	typedef void (*CallbackLog)(char*);
	typedef void (*CallbackData)(short*, int);
	typedef void (*CallbackConnect)(int, char*);
	typedef void (*CallbackTrigger)(void);
	void log(char *lpData, ...);

public:
	TestScope();
	~TestScope();
	int Connect(void);
	int Disconnect(void);
	int RecStart(void);				///< start recording
	int RecStop(void);              ///< stop recording
	CallbackLog callbackLog;
	CallbackData callbackData;
	CallbackConnect callbackConnect;
	CallbackTrigger callbackTrigger;
	void ConnectCb(int state, char* msg) {
		if (callbackConnect)
			callbackConnect(state, msg);
	}
	/** \brief Request manual triggering
		\return 0 on success
	*/
	int ManualTrigger(void);
	int SetTriggerType(enum E_TRIGGER_TYPE);
	int SetCouplingType(enum E_COUPLING_TYPE);
	/** \brief Set capture buffer size
		\param size number of samples
	*/
	int SetBufferSize(int size);
	int SetSensitivity(int id);
	int SetSampling(int id);
	int SetTriggerLevel(int level);
};
extern TestScope testScope;


#endif
